AiProcessResponse class

Constructors

AiProcessResponse({required bool success, Map<String, dynamic>? results, Map<String, dynamic>? steps, int? totalLatencyMs, Map<String, dynamic>? limits, String? message, String? error, Map<String, dynamic>? completedSteps})
const
AiProcessResponse.fromJson(Map<String, dynamic> json)
factory

Properties

completedSteps Map<String, dynamic>?
final
error String?
final
hashCode int
The hash code for this object.
no setterinherited
limits Map<String, dynamic>?
final
message String?
final
results Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
steps Map<String, dynamic>?
final
success bool
final
totalLatencyMs int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited